/*******************************************************************************
 * Copyright (c) 2009, 2013 Oracle and/or its affiliates. All rights reserved.
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0
 * which accompanies this distribution.
 * The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
 * and the Eclipse Distribution License is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * Contributors:
 *     Oracle - initial API and implementation
 *
 ******************************************************************************/
package org.eclipse.persistence.tools.utility.model.value;

import org.eclipse.persistence.tools.utility.model.event.PropertyChangeEvent;

/**
 * A simple implementation of {@link ModifiablePropertyValueModel} that actually
 * ... <em>isn't</em> ... modifiable.  It can however be used in places that require a
 * {@link ModifiablePropertyValueModel} and where the developer is sure that no
 * attempt will be made to write to it.
 */
public class ReadOnlyModifiablePropertyValueModelWrapper<T>
	extends PropertyValueModelWrapper<T>
	implements ModifiablePropertyValueModel<T>
{
	public ReadOnlyModifiablePropertyValueModelWrapper(PropertyValueModel<? extends T> valueModel) {
		super(valueModel);
	}


	@Override
	public T getValue() {
		return this.valueModel.getValue();
	}

	@Override
	public void setValue(T value) {
		throw new UnsupportedOperationException();
	}

	@Override
	protected void wrappedValueChanged(PropertyChangeEvent event) {
		this.firePropertyChanged(event.clone(this));
	}

	@Override
	public void toString(StringBuilder sb) {
		sb.append(this.getValue());
	}
}